{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d MMM, y G",
    GyMMMd => "d MMM, y G",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d-M",
    MMM => "LLL",
    MMMEd => "E d MMM",
    MMMMEd => "E d MMMM",
    "MMMMW-count-other" => "MMMM \N{U+11103}\N{U+1112c}\N{U+11122}\N{U+11134} \N{U+11120}\N{U+11134} \N{U+11125}\N{U+1111b}\N{U+11134}\N{U+11116} W",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    MMdd => "dd-MM",
    Md => "d/M",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, d/M/y",
    yMM => "MM-y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM, y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM, y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "Y \N{U+11103}\N{U+1112c}\N{U+11122}\N{U+11134} \N{U+11116}\N{U+11127}\N{U+1111f}\N{U+11134} \N{U+11125}\N{U+1111b}\N{U+11134}\N{U+11116} w",
  },
  code => "ccp-BD",
  date_format_full => "EEEE, d MMMM, y",
  date_format_long => "d MMMM, y",
  date_format_medium => "d MMM, y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+11125}\N{U+11127}\N{U+1111f}\N{U+11134}",
    "\N{U+1111f}\N{U+11127}\N{U+11101}\N{U+11109}\N{U+11127}\N{U+11123}\N{U+11134}",
    "\N{U+1111d}\N{U+1112a}\N{U+11116}\N{U+11134}",
    "\N{U+1111d}\N{U+11133}\N{U+11122}\N{U+11128}\N{U+11125}\N{U+1112a}\N{U+1111b}\N{U+11134}",
    "\N{U+11125}\N{U+1112a}\N{U+11107}\N{U+11134}\N{U+11107}\N{U+1112e}\N{U+11122}\N{U+11134}",
    "\N{U+11125}\N{U+11127}\N{U+1111a}\N{U+11128}",
    "\N{U+11122}\N{U+11127}\N{U+1111d}\N{U+11128}",
  ],
  day_format_narrow => [
    "\N{U+11125}\N{U+11127}",
    "\N{U+1111f}\N{U+11127}",
    "\N{U+1111d}\N{U+1112a}",
    "\N{U+1111d}\N{U+11133}\N{U+11122}\N{U+11128}",
    "\N{U+11125}\N{U+1112a}",
    "\N{U+11125}\N{U+11127}",
    "\N{U+11122}\N{U+11127}",
  ],
  day_format_wide => [
    "\N{U+11125}\N{U+11127}\N{U+1111f}\N{U+11134}\N{U+1111d}\N{U+11122}\N{U+11134}",
    "\N{U+1111f}\N{U+11127}\N{U+11101}\N{U+11109}\N{U+11127}\N{U+11123}\N{U+11134}\N{U+1111d}\N{U+11122}\N{U+11134}",
    "\N{U+1111d}\N{U+1112a}\N{U+11116}\N{U+11134}\N{U+1111d}\N{U+11122}\N{U+11134}",
    "\N{U+1111d}\N{U+11133}\N{U+11122}\N{U+11128}\N{U+11125}\N{U+1112a}\N{U+1111b}\N{U+11134}\N{U+1111d}\N{U+11122}\N{U+11134}",
    "\N{U+11125}\N{U+1112a}\N{U+11107}\N{U+11134}\N{U+11107}\N{U+1112e}\N{U+11122}\N{U+11134}\N{U+1111d}\N{U+11122}\N{U+11134}",
    "\N{U+11125}\N{U+11127}\N{U+1111a}\N{U+11128}\N{U+1111d}\N{U+11122}\N{U+11134}",
    "\N{U+11122}\N{U+11127}\N{U+1111d}\N{U+11128}\N{U+1111d}\N{U+11122}\N{U+11134}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+11125}\N{U+11127}\N{U+1111f}\N{U+11134}",
    "\N{U+1111f}\N{U+11127}\N{U+11101}\N{U+11109}\N{U+11127}\N{U+11123}\N{U+11134}",
    "\N{U+1111d}\N{U+1112a}\N{U+11116}\N{U+11134}",
    "\N{U+1111d}\N{U+11133}\N{U+11122}\N{U+11128}\N{U+11125}\N{U+1112a}\N{U+1111b}\N{U+11134}",
    "\N{U+11125}\N{U+1112a}\N{U+11107}\N{U+11134}\N{U+11107}\N{U+1112e}\N{U+11122}\N{U+11134}",
    "\N{U+11125}\N{U+11127}\N{U+1111a}\N{U+11128}",
    "\N{U+11122}\N{U+11127}\N{U+1111d}\N{U+11128}",
  ],
  day_stand_alone_narrow => [
    "\N{U+11125}\N{U+11127}",
    "\N{U+1111f}\N{U+11127}",
    "\N{U+1111d}\N{U+1112a}",
    "\N{U+1111d}\N{U+11133}\N{U+11122}\N{U+11128}",
    "\N{U+11125}\N{U+1112a}",
    "\N{U+11125}\N{U+11127}",
    "\N{U+11122}\N{U+11127}",
  ],
  day_stand_alone_wide => [
    "\N{U+11125}\N{U+11127}\N{U+1111f}\N{U+11134}\N{U+1111d}\N{U+11122}\N{U+11134}",
    "\N{U+1111f}\N{U+11127}\N{U+11101}\N{U+11109}\N{U+11127}\N{U+11123}\N{U+11134}\N{U+1111d}\N{U+11122}\N{U+11134}",
    "\N{U+1111d}\N{U+1112a}\N{U+11116}\N{U+11134}\N{U+1111d}\N{U+11122}\N{U+11134}",
    "\N{U+1111d}\N{U+11133}\N{U+11122}\N{U+11128}\N{U+11125}\N{U+1112a}\N{U+1111b}\N{U+11134}\N{U+1111d}\N{U+11122}\N{U+11134}",
    "\N{U+11125}\N{U+1112a}\N{U+11107}\N{U+11134}\N{U+11107}\N{U+1112e}\N{U+11122}\N{U+11134}\N{U+1111d}\N{U+11122}\N{U+11134}",
    "\N{U+11125}\N{U+11127}\N{U+1111a}\N{U+11128}\N{U+1111d}\N{U+11122}\N{U+11134}",
    "\N{U+11122}\N{U+11127}\N{U+1111d}\N{U+11128}\N{U+1111d}\N{U+11122}\N{U+11134}",
  ],
  era_abbreviated => [
    "\N{U+11108}\N{U+11133}\N{U+11122}\N{U+11128}\N{U+1110c}\N{U+11134}\N{U+11111}\N{U+11134}\N{U+1111b}\N{U+1112b}\N{U+11122}\N{U+11134}\N{U+1111d}\N{U+11127}",
    "\N{U+11108}\N{U+11133}\N{U+11122}\N{U+11128}\N{U+1110c}\N{U+11134}\N{U+11111}\N{U+1111b}\N{U+11134}\N{U+11118}\N{U+11127}",
  ],
  era_narrow => [
    "\N{U+11108}\N{U+11133}\N{U+11122}\N{U+11128}\N{U+1110c}\N{U+11134}\N{U+11111}\N{U+11134}\N{U+1111b}\N{U+1112b}\N{U+11122}\N{U+11134}\N{U+1111d}\N{U+11127}",
    "\N{U+11108}\N{U+11133}\N{U+11122}\N{U+11128}\N{U+1110c}\N{U+11134}\N{U+11111}\N{U+1111b}\N{U+11134}\N{U+11118}\N{U+11127}",
  ],
  era_wide => [
    "\N{U+11108}\N{U+11133}\N{U+11122}\N{U+11128}\N{U+1110c}\N{U+11134}\N{U+11111}\N{U+11134}\N{U+1111b}\N{U+1112b}\N{U+11122}\N{U+11134}\N{U+1111d}\N{U+11127}",
    "\N{U+11108}\N{U+11133}\N{U+11122}\N{U+11128}\N{U+1110c}\N{U+11134}\N{U+11111}\N{U+1111b}\N{U+11134}\N{U+11118}\N{U+11127}",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Chakma",
  month_format_abbreviated => [
    "\N{U+1110e}\N{U+1111a}\N{U+1112a}",
    "\N{U+1111c}\N{U+1112c}\N{U+1111b}\N{U+11134}",
    "\N{U+1111f}\N{U+11122}\N{U+11134}\N{U+1110c}\N{U+11127}",
    "\N{U+11103}\N{U+1112c}\N{U+1111b}\N{U+11133}\N{U+11122}\N{U+11128}\N{U+11123}\N{U+11134}",
    "\N{U+1111f}\N{U+1112c}",
    "\N{U+1110e}\N{U+1112a}\N{U+1111a}\N{U+11134}",
    "\N{U+1110e}\N{U+1112a}\N{U+11123}\N{U+1112d}",
    "\N{U+11103}\N{U+11109}\N{U+11127}\N{U+1110c}\N{U+11134}\N{U+11111}\N{U+11134}",
    "\N{U+11125}\N{U+1112c}\N{U+1111b}\N{U+11134}\N{U+11111}\N{U+1112c}\N{U+1111f}\N{U+11134}\N{U+1111d}\N{U+11127}\N{U+11122}\N{U+11134}",
    "\N{U+11103}\N{U+11127}\N{U+11107}\N{U+11134}\N{U+11111}\N{U+1112e}\N{U+1111d}\N{U+11127}\N{U+11122}\N{U+11134}",
    "\N{U+1111a}\N{U+11127}\N{U+1111e}\N{U+1112c}\N{U+1111f}\N{U+11134}\N{U+1111d}\N{U+11127}\N{U+11122}\N{U+11134}",
    "\N{U+11113}\N{U+11128}\N{U+11125}\N{U+1112c}\N{U+1111f}\N{U+11134}\N{U+1111d}\N{U+11122}\N{U+11134}",
  ],
  month_format_narrow => [
    "\N{U+1110e}",
    "\N{U+1111c}\N{U+1112c}",
    "\N{U+1111f}",
    "\N{U+11103}\N{U+1112c}",
    "\N{U+1111f}\N{U+1112c}",
    "\N{U+1110e}\N{U+1112a}\N{U+1111a}\N{U+11134}",
    "\N{U+1110e}\N{U+1112a}",
    "\N{U+11103}",
    "\N{U+11125}\N{U+1112c}",
    "\N{U+11103}\N{U+11127}",
    "\N{U+1111a}\N{U+11127}",
    "\N{U+11113}\N{U+11128}",
  ],
  month_format_wide => [
    "\N{U+1110e}\N{U+1111a}\N{U+1112a}\N{U+11120}\N{U+11122}\N{U+11128}",
    "\N{U+1111c}\N{U+1112c}\N{U+1111b}\N{U+11134}\N{U+1111d}\N{U+11133}\N{U+11122}\N{U+1112a}\N{U+11120}\N{U+11122}\N{U+11128}",
    "\N{U+1111f}\N{U+11122}\N{U+11134}\N{U+1110c}\N{U+11127}",
    "\N{U+11103}\N{U+1112c}\N{U+1111b}\N{U+11133}\N{U+11122}\N{U+11128}\N{U+11123}\N{U+11134}",
    "\N{U+1111f}\N{U+1112c}",
    "\N{U+1110e}\N{U+1112a}\N{U+1111a}\N{U+11134}",
    "\N{U+1110e}\N{U+1112a}\N{U+11123}\N{U+1112d}",
    "\N{U+11103}\N{U+11109}\N{U+11127}\N{U+1110c}\N{U+11134}\N{U+11111}\N{U+11134}",
    "\N{U+11125}\N{U+1112c}\N{U+1111b}\N{U+11134}\N{U+11111}\N{U+1112c}\N{U+1111f}\N{U+11134}\N{U+1111d}\N{U+11127}\N{U+11122}\N{U+11134}",
    "\N{U+11103}\N{U+11127}\N{U+11107}\N{U+11134}\N{U+11111}\N{U+1112c}\N{U+1111d}\N{U+11127}\N{U+11122}\N{U+11134}",
    "\N{U+1111a}\N{U+11127}\N{U+1111e}\N{U+1112c}\N{U+1111f}\N{U+11134}\N{U+1111d}\N{U+11127}\N{U+11122}\N{U+11134}",
    "\N{U+11113}\N{U+11128}\N{U+11125}\N{U+1112c}\N{U+1111f}\N{U+11134}\N{U+1111d}\N{U+11127}\N{U+11122}\N{U+11134}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+1110e}\N{U+1111a}\N{U+1112a}\N{U+11120}\N{U+11122}\N{U+11128}",
    "\N{U+1111c}\N{U+1112c}\N{U+1111b}\N{U+11134}\N{U+1111d}\N{U+11133}\N{U+11122}\N{U+1112a}\N{U+11120}\N{U+11122}\N{U+11128}",
    "\N{U+1111f}\N{U+11122}\N{U+11134}\N{U+1110c}\N{U+11127}",
    "\N{U+11103}\N{U+1112c}\N{U+1111b}\N{U+11133}\N{U+11122}\N{U+11128}\N{U+11123}\N{U+11134}",
    "\N{U+1111f}\N{U+1112c}",
    "\N{U+1110e}\N{U+1112a}\N{U+1111a}\N{U+11134}",
    "\N{U+1110e}\N{U+1112a}\N{U+11123}\N{U+1112d}",
    "\N{U+11103}\N{U+11109}\N{U+11127}\N{U+1110c}\N{U+11134}\N{U+11111}\N{U+11134}",
    "\N{U+11125}\N{U+1112c}\N{U+1111b}\N{U+11134}\N{U+11111}\N{U+1112c}\N{U+1111f}\N{U+11134}\N{U+1111d}\N{U+11127}\N{U+11122}\N{U+11134}",
    "\N{U+11103}\N{U+11127}\N{U+11107}\N{U+11134}\N{U+11111}\N{U+1112e}\N{U+1111d}\N{U+11127}\N{U+11122}\N{U+11134}",
    "\N{U+1111a}\N{U+11127}\N{U+1111e}\N{U+1112c}\N{U+1111f}\N{U+11134}\N{U+1111d}\N{U+11127}\N{U+11122}\N{U+11134}",
    "\N{U+11113}\N{U+11128}\N{U+11125}\N{U+1112c}\N{U+1111f}\N{U+11134}\N{U+1111d}\N{U+11127}\N{U+11122}\N{U+11134}",
  ],
  month_stand_alone_narrow => [
    "\N{U+1110e}",
    "\N{U+1111c}\N{U+1112c}",
    "\N{U+1111f}",
    "\N{U+11103}\N{U+1112c}",
    "\N{U+1111f}\N{U+1112c}",
    "\N{U+1110e}\N{U+1112a}\N{U+1111a}\N{U+11134}",
    "\N{U+1110e}\N{U+1112a}",
    "\N{U+11103}",
    "\N{U+11125}\N{U+1112c}",
    "\N{U+11103}\N{U+11127}",
    "\N{U+1111a}\N{U+11127}",
    "\N{U+11113}\N{U+11128}",
  ],
  month_stand_alone_wide => [
    "\N{U+1110e}\N{U+1111a}\N{U+1112a}\N{U+11120}\N{U+11122}\N{U+11128}",
    "\N{U+1111c}\N{U+1112c}\N{U+1111b}\N{U+11134}\N{U+1111d}\N{U+11133}\N{U+11122}\N{U+1112a}\N{U+11120}\N{U+11122}\N{U+11128}",
    "\N{U+1111f}\N{U+11122}\N{U+11134}\N{U+1110c}\N{U+11127}",
    "\N{U+11103}\N{U+1112c}\N{U+1111b}\N{U+11133}\N{U+11122}\N{U+11128}\N{U+11123}\N{U+11134}",
    "\N{U+1111f}\N{U+1112c}",
    "\N{U+1110e}\N{U+1112a}\N{U+1111a}\N{U+11134}",
    "\N{U+1110e}\N{U+1112a}\N{U+11123}\N{U+1112d}",
    "\N{U+11103}\N{U+11109}\N{U+11127}\N{U+1110c}\N{U+11134}\N{U+11111}\N{U+11134}",
    "\N{U+11125}\N{U+1112c}\N{U+1111b}\N{U+11134}\N{U+11111}\N{U+1112c}\N{U+1111f}\N{U+11134}\N{U+1111d}\N{U+11127}\N{U+11122}\N{U+11134}",
    "\N{U+11103}\N{U+11127}\N{U+11107}\N{U+11134}\N{U+11111}\N{U+1112e}\N{U+1111d}\N{U+11127}\N{U+11122}\N{U+11134}",
    "\N{U+1111a}\N{U+11127}\N{U+1111e}\N{U+1112c}\N{U+1111f}\N{U+11134}\N{U+1111d}\N{U+11127}\N{U+11122}\N{U+11134}",
    "\N{U+11113}\N{U+11128}\N{U+11125}\N{U+1112c}\N{U+1111f}\N{U+11134}\N{U+1111d}\N{U+11127}\N{U+11122}\N{U+11134}",
  ],
  name => "Chakma Bangladesh",
  native_language => "\N{U+1110c}\N{U+1110b}\N{U+11134}\N{U+1111f}\N{U+11133}\N{U+11126}",
  native_name => "\N{U+1110c}\N{U+1110b}\N{U+11134}\N{U+1111f}\N{U+11133}\N{U+11126} \N{U+1111d}\N{U+11101}\N{U+11123}\N{U+11118}\N{U+1112c}\N{U+1110c}\N{U+11134}",
  native_script => undef,
  native_territory => "\N{U+1111d}\N{U+11101}\N{U+11123}\N{U+11118}\N{U+1112c}\N{U+1110c}\N{U+11134}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    "\N{U+11137}",
    "\N{U+11138}",
    "\N{U+11139}",
    "\N{U+1113a}",
  ],
  quarter_format_wide => [
    "\N{U+11116}\N{U+11128}\N{U+1111a}\N{U+11134}\N{U+1111f}\N{U+1110e}\N{U+11127}\N{U+11122}\N{U+11134}",
    "\N{U+11118}\N{U+11128} \N{U+1111b}\N{U+11133}\N{U+11106}\N{U+11118}\N{U+11133}\N{U+11120}\N{U+1112c} \N{U+11116}\N{U+11128}\N{U+1111a}\N{U+11134}\N{U+1111f}\N{U+1110e}\N{U+11127}\N{U+11122}\N{U+11134}",
    "\N{U+11116}\N{U+11128}\N{U+1111a}\N{U+11134} \N{U+1111b}\N{U+11133}\N{U+11106}\N{U+11118}\N{U+11133}\N{U+11120}\N{U+1112c} \N{U+11116}\N{U+11128}\N{U+1111a}\N{U+11134}\N{U+1111f}\N{U+1110e}\N{U+11127}\N{U+11122}\N{U+11134}",
    "\N{U+1110c}\N{U+11133}\N{U+11106}\N{U+1112c}\N{U+11122}\N{U+11134} \N{U+1111b}\N{U+11133}\N{U+11106}\N{U+11118}\N{U+11133}\N{U+11120}\N{U+1112c} \N{U+11116}\N{U+11128}\N{U+1111a}\N{U+11134}\N{U+1111f}\N{U+1110e}\N{U+11127}\N{U+11122}\N{U+11134}",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    "\N{U+11137}",
    "\N{U+11138}",
    "\N{U+11139}",
    "\N{U+1113a}",
  ],
  quarter_stand_alone_wide => [
    "\N{U+11116}\N{U+11128}\N{U+1111a}\N{U+11134}\N{U+1111f}\N{U+1110e}\N{U+11127}\N{U+11122}\N{U+11134}",
    "\N{U+11118}\N{U+11128} \N{U+1111b}\N{U+11133}\N{U+11106}\N{U+11118}\N{U+11133}\N{U+11120}\N{U+1112c} \N{U+11116}\N{U+11128}\N{U+1111a}\N{U+11134}\N{U+1111f}\N{U+1110e}\N{U+11127}\N{U+11122}\N{U+11134}",
    "\N{U+11116}\N{U+11128}\N{U+1111a}\N{U+11134} \N{U+1111b}\N{U+11133}\N{U+11106}\N{U+11118}\N{U+11133}\N{U+11120}\N{U+1112c} \N{U+11116}\N{U+11128}\N{U+1111a}\N{U+11134}\N{U+1111f}\N{U+1110e}\N{U+11127}\N{U+11122}\N{U+11134}",
    "\N{U+1110c}\N{U+11133}\N{U+11106}\N{U+1112c}\N{U+11122}\N{U+11134} \N{U+1111b}\N{U+11133}\N{U+11106}\N{U+11118}\N{U+11133}\N{U+11120}\N{U+1112c} \N{U+11116}\N{U+11128}\N{U+1111a}\N{U+11134}\N{U+1111f}\N{U+1110e}\N{U+11127}\N{U+11122}\N{U+11134}",
  ],
  script => undef,
  territory => "Bangladesh",
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 46,
}
